Documentation
¶
Index ¶
Constants ¶
const ( DoQNoError = 0x0 // No error. This is used when the connection or stream needs to be closed, but there is no error to signal. DoQInternalError = 0x1 // The DoQ implementation encountered an internal error and is incapable of pursuing the transaction or the connection. DoQProtocolError = 0x2 // The DoQ implementation encountered a protocol error and is forcibly aborting the connection. DoQRequestCancelled = 0x3 // A DoQ client uses this to signal that it wants to cancel an outstanding transaction. DoQExcessiveLoad = 0x4 // A DoQ implementation uses this to signal when closing a connection due to excessive load. DoQUnspecifiedError = 0x5 // A DoQ implementation uses this in the absence of a more specific error code. DoQErrorReserved = 0xd098ea5e // Alternative error code used for tests. )
DoQ Error Codes https://datatracker.ietf.org/doc/html/rfc9250#section-8.4
const ODoHContentType = "application/oblivious-dns-message"
Variables ¶
var Types = []Type{TypePlain, TypeTCP, TypeTLS, TypeHTTP, TypeQUIC, TypeDNSCrypt}
Types is a list of all supported transports
Functions ¶
This section is empty.
Types ¶
type DNSCrypt ¶ added in v0.13.0
type HTTP ¶
type HTTP struct {
Common
TLSConfig *tls.Config
UserAgent string
Method string
HTTP2, HTTP3 bool
NoPMTUd bool
Headers map[string][]string
// contains filtered or unexported fields
}
HTTP makes a DNS query over HTTP(s)
type ODoH ¶
type ODoH struct {
Common // Server is the target
Proxy string
TLSConfig *tls.Config
// contains filtered or unexported fields
}
ODoH makes a DNS query over ODoH
type Plain ¶
Plain makes a DNS query over TCP or UDP (with TCP fallback)
type QUIC ¶
type QUIC struct {
Common
TLSConfig *tls.Config
PMTUD bool
AddLengthPrefix bool
// contains filtered or unexported fields
}
QUIC makes a DNS query over QUIC
Click to show internal directories.
Click to hide internal directories.